@@ -191,7 +191,7 @@ use Scalar::Util 'refaddr';
 use base 'Exporter';
 use v5.14;
 
-our $VERSION = '0.32';
+our $VERSION = '0.33';
 
 our @EXPORT = qw{
     one_row
@@ -2010,7 +2010,8 @@ sub for_rows {
             my ($sth, $ncn) = @_;
             my $rows = 0;
             my $row;
-            local $_{mysql_use_result} = 1 if $connector_driver eq 'mysql';
+            my $dbh = $_;
+            local $dbh->{mysql_use_result} = 1 if $connector_driver eq 'mysql';
             local $_;
             while ($row = $sth->fetch) {
                 ++$rows;
